==> icebear_v1_4_1.tar: client/help/homepage/index.php <==
<?php /**
Application-specific homepage help should not go in this file.
Instead, add it into extensions.php in this directory.
*/
include_once($_SERVER['DOCUMENT_ROOT'].'/client/help/_common/helphead.php');
?>

<h1>Homepage</h1>

<p>The homepage is your starting point. It is made up of a number of "bricks", each containing useful information. The exact layout 
of these bricks is configurable, so you can customise your homepage to suit the way you work.</p>

<h2>Customising your homepage</h2>
<p>To begin, first click the gear wheel icon in the top right.</p>
<h3>Removing bricks</h3>
<p>Each brick will now have an X in its top right corner. Click this to remove the brick from your homepage, and click OK when asked 
to confirm. You can add the brick again later if you want to.</p>
<h3>Moving bricks</h3>
<p>You can move bricks around on your homepage. Click and hold the title bar of the brick, drag the brick to its new position, and
release the mouse button. If the brick won't fit where you put it, it will go back to its original position.</p>
<h3>Adding new bricks</h3>
<p>There may be more bricks available to you. If you have space on your homepage, you can add them.</p>
<p>To begin, click an empty space on your homepage. A window opens with the list of available bricks; bricks already on your homepage 
aren't shown here:</p>
<figure>
	<img alt="" src="bricklist.png"/>
	<figcaption>A list of homepage bricks that can be added.</figcaption>
</figure>

<p>Each brick has a name and a description. The icon on the left shows you how many rows and columns the brick will take up on your 
homepage; most bricks are 1x1, but some may take up more space.</p>
<p>Click the brick that you want. It will be added to your homepage, in the position you chose. You can move it around if you want to.</p>

<?php include 'extensions.php'; ?>
<?php
include_once($_SERVER['DOCUMENT_ROOT'].'/client/help/_common/helpfoot.php');
?>

==> icebear_v1_12_0.tar: client/help/homepage/index.php <==
<?php /**
Application-specific homepage help should not go in this file.
Instead, add it into extensions.php in this directory.
*/
include_once(dirname(__DIR__,3).'/client/help/_common/helphead.php');
?>

<h1>Homepage</h1>

<p>The homepage is your starting point. It is made up of a number of "bricks", each containing useful information. The exact layout 
of these bricks is configurable, so you can customise your homepage to suit the way you work.</p>

<h2>Customising your homepage</h2>
<p>To begin, first click the gear wheel icon in the top right.</p>
<h3>Removing bricks</h3>
<p>Each brick will now have an X in its top right corner. Click this to remove the brick from your homepage, and click OK when asked 
to confirm. You can add the brick again later if you want to.</p>
<h3>Moving bricks</h3>
<p>You can move bricks around on your homepage. Click and hold the title bar of the brick, drag the brick to its new position, and
release the mouse button. If the brick won't fit where you put it, it will go back to its original position.</p>
<h3>Adding new bricks</h3>
<p>There may be more bricks available to you. If you have space on your homepage, you can add them.</p>
<p>To begin, click an empty space on your homepage. A window opens with the list of available bricks; bricks already on your homepage 
aren't shown here:</p>
<figure>
	<img alt="" src="bricklist.png"/>
	<figcaption>A list of homepage bricks that can be added.</figcaption>
</figure>

<p>Each brick has a name and a description. The icon on the left shows you how many rows and columns the brick will take up on your 
homepage; most bricks are 1x1, but some may take up more space.</p>
<p>Click the brick that you want. It will be added to your homepage, in the position you chose. You can move it around if you want to.</p>

<?php include 'extensions.php'; ?>
<?php
include_once(dirname(__DIR__,3).'/client/help/_common/helpfoot.php');
?>
